@@ -8,6 +8,7 @@ var mout = require('mout');
 var cordova = require('cordova');
 var chalk = require('chalk');
 var ionicUtils = require('../utils');
+var mkdir = require('mkdirp');
 
 var appPath = path.join(process.cwd(), 'app');
 
@@ -151,6 +152,8 @@ module.exports = generators.Base.extend({
                 fs.unlinkSync(file);
             }
        });
+      
+      mkdir.sync('local_plugins');
       // Copies the contents of the generator example app
       // directory into your users new application path
       this.sourceRoot(path.join(__dirname, '../templates/'));
